**Eigen is a C++ template library for linear algebra: matrices, vectors, numerical solvers, and related algorithms.**

For more information go to http://eigen.tuxfamily.org/.

For ***pull request*** please only use the official repository at https://bitbucket.org/eigen/eigen.

For ***bug reports*** and ***feature requests*** go to http://eigen.tuxfamily.org/bz.
